If you are submitting a bug report or feature request, please use the respective
issue template.


## Issue description

Provide a short description.

## Code example

Please try to provide a minimal example to repro the issue.
Error messages and stack traces are also helpful.

## System Info
Please provide information about your setup, including
- BoTorch Version (run `print(botorch.__version__)`
- GPyTorch Version (run `print(gpytorch.__version__)`
- PyTorch Version (run `print(torch.__version__)`
- Computer OS
